ZegoSuperBoardManager class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addImage({required ZegoSuperBoardViewImageType type, required String address, required int positionX, required int positionY}) Future<ZegoSuperBoardError>
Insert images into a whiteboard.
addText({required String text, required int positionX, required int positionY}) Future<ZegoSuperBoardError>
Add custom text to a whiteboard view.
cacheFile({required String fileID}) Future<Map?>
Cache files to a local directory.
cancelCacheFile({required int seq}) Future<ZegoSuperBoardError>
Cancel the caching operation during file caching.
cancelUploadFile({required int seq}) Future<ZegoSuperBoardError>
Cancel the upload operation during file upload.
clear() Future<void>
Call this API to clear resources in a room before leaving the room.
clearAllPage() Future<ZegoSuperBoardError>
Clear diagram elements on all pages of a whiteboard.
clearBackgroundImage() Future<ZegoSuperBoardError>
Clear the background image of a whiteboard.
clearCache() Future<void>
Clear cache resources related to files and whiteboards.
clearCurrentPage() Future<ZegoSuperBoardError>
Clear diagram elements on the current page of a whiteboard.
clearSelected() Future<ZegoSuperBoardError>
Delete selected diagram elements.
createCanvasView(dynamic onViewCreated(int viewID), {Key? key}) Future<Widget?>
Create a canvas view.
createFileView(ZegoCreateFileConfig config) Future<ZegoSuperBoardManagerCreateResult>
Create a file whiteboard.
createWhiteboardView({required ZegoCreateWhiteboardConfig config}) Future<ZegoSuperBoardManagerCreateResult>
Create a pure whiteboard.
destroyCanvasView(int viewID) Future<bool>
Destroy a canvas view.
destroySuperBoardSubView(String? uniqueID) Future<ZegoSuperBoardError>
Destroy the specified SuperBoardSubView.
enableCustomCursor({required bool enableCustomCursor}) Future<void>
Description: Set whether to enable custom cursor. If it is set to true, the custom cursor is displayed. The default value is true.
enableHandwriting({required bool enableHandwriting}) Future<void>
Description: Set whether to enable the handwriting effect for drawings on a whiteboard. If it is set to true, the handwriting effect is enabled for drawings on a whiteboard.
enableRemoteCursorVisible({required bool enableRemoteCursorVisible}) Future<void>
Description: Set whether to display the remote cursor. If it is set to true, the remote cursor is displayed. The default value is true.
enableResponseScale({required bool enableResponseScale}) Future<void>
Description: After enableResponseScale is enabled, the local client can respond to zooming operations performed by other users in the room. The prerequisite is that the remote client synchronizes zooming operations to other users in the room.
enableSuperBoardView({required bool? enable}) Future<void>
Set whether to use SuperBoardView.
enableSyncScale({required bool enableSyncScale}) Future<void>
Description: After enableSyncScale is enabled, whiteboard zooming at the local client can be synchronized with the remote client. Whether the whiteboard of the remote client is zoomed in or out with that at the local client depends on whether enableResponseScale is enabled.
flipToNextPage() Future<ZegoSuperBoardError>
Redirect to the previous page.
flipToPage({required int targetPage}) Future<ZegoSuperBoardError>
Redirect to the specified page.
flipToPrePage() Future<ZegoSuperBoardError>
Redirect to the previous page.
getBrushColor() Future<String?>
Description: Get the pen color for new drawings on the whiteboard after the pen tool is selected.
getBrushSize() Future<int>
Get Pen size.
getCurrentPage() Future<int>
Description: Obtain the page number of the currently displayed content.
getCurrentSheetName() Future<String?>
Description: Obtain the name of the currently displayed sheet. For non-excel files, nil is returned.
getCurrentSuperBoardSubViewModel() Future<ZegoSuperBoardSubViewModel?>
Description: Obtain model data of the ZegoSuperBoardSubView.
getCustomizedConfig({required String? key}) Future<String?>
Obtain the values of set configuration items.
getCustomText() Future<String?>
Description: Customize the default text for the custom text tool.
getExcelSheetNameList() Future<List?>
Description: Obtain the names of all sheets in the Excel file.
getFontSize() Future<int>
Description: Get the font size for new text on the whiteboard after the text tool is selected.
getPageCount() Future<int>
Description: Obtain the total number of pages.
getPPTNotes({required int page}) Future<String?>
Obtain notes on the specified page of a PPT file.
getScaleFactor() Future<double>
Description: Obtain the currently displayed zooming ratio.
getSDKVersion() Future<String?>
Obtain the SDK version number.
getSuperBoardSubView(String? uniqueID) Future<void>
Obtain the specified SuperBoardSubView object.
getSuperBoardSubViewModelList() Future<List<ZegoSuperBoardSubViewModel>>
Description: Use superBoardSubViewModelList to obtain the number of superBoardSubView objects in the current room and superBoardSubView information.
getThumbnailUrlList() Future<List?>
Obtain the thumbnail list of the current file. Only PDF, PPT, animated PPT, and H5 files are supported.
getToolType() Future<ZegoSuperBoardTool>
Description: Get different tool types to draw different diagram elements on a whiteboard.
getVisibleSize() Future<Map?>
Description: Obtain the size of the SuperBoardSubView visible area.
initWithConfig(ZegoSuperBoardInitConfig config) Future<ZegoSuperBoardError>
Initialize the ZegoSuperBoard SDK.
inputText() Future<ZegoSuperBoardError>
Add text to a whiteboard view. After this API is called, an input box is displayed from the bottom of the whiteboard.
isEnabledCustomCursor() Future<bool>
Description: Get whether to enable custom cursor. If it is set to true, the custom cursor is displayed. The default value is true.
isEnabledHandwriting() Future<bool>
Description: Get whether to enable the handwriting effect for drawings on a whiteboard. If it is set to true, the handwriting effect is enabled for drawings on a whiteboard.
isEnabledRemoteCursorVisible() Future<bool>
Description: Get whether to display the remote cursor. If it is set to true, the remote cursor is displayed. The default value is true.
isEnabledResponseScale() Future<bool>
Description: After enableResponseScale is enabled, the local client can respond to zooming operations performed by other users in the room. The prerequisite is that the remote client synchronizes zooming operations to other users in the room.
isEnabledSyncScale() Future<bool>
Description: After enableSyncScale is enabled, whiteboard zooming at the local client can be synchronized with the remote client. Whether the whiteboard of the remote client is zoomed in or out with that at the local client depends on whether enableResponseScale is enabled.
isExistCurrentSuperBoardSubView() Future<bool>
Description: Determine if there is a CurrentSuperBoardSubView Supported version: 2.0.0 and above
isFontBold() Future<bool>
Description: Get isFontBold to YES to bold newly added text on the whiteboard after the text tool is selected.
isFontItalic() Future<bool>
Description: Determine whether to get the italic effect for newly added text on the whiteboard after the text tool is selected.
nextStep() Future<ZegoSuperBoardError>
Redirect to the next animation step.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preStep() Future<ZegoSuperBoardError>
Redirect to the previous animation step.
queryFileCached({required String fileID}) Future<Map?>
Check whether a file is cached.
querySuperBoardSubViewList() Future<ZegoQuerySuperBoardSubViewResult>
Query the list of existing SuperBoardSubView objects from the server.
redo() Future<void>
Restore the previous operation canceled on a whiteboard.
renewToken({required String? token}) Future<void>
Set authentication token
setBackgroundImage({required String address, required ZegoSuperBoardViewImageFitMode mode}) Future<ZegoSuperBoardError>
Set a background image for a whiteboard.
setBrushColor({required String? rgbValue}) Future<void>
Description: Set the pen color for new drawings on the whiteboard after the pen tool is selected.
setBrushSize({required int brushSize}) Future<void>
Set Pen size.
setCustomCursorAttribute({required ZegoSuperBoardViewCursorType type, required ZegoSuperBoardCursorAttribute attribute}) Future<ZegoSuperBoardError>
Set the cursor style.
setCustomFontFromAsset({required String regularAssetPath, required String boldAssetPath}) Future<void>
Set the cursor style.
setCustomizedConfig({required String? key, required String? value}) Future<void>
Set configuration items. For example: When the key is logPath, the value is the SDK log directory address. When the key is cachePath, the value is the SDK cache directory address.
setCustomText({required String? customText}) Future<void>
Description: Customize the default text for the custom text tool.
setFontBold({required bool isFontBold}) Future<void>
Description: Set isFontBold to YES to bold newly added text on the whiteboard after the text tool is selected.
setFontItalic({required bool isFontItalic}) Future<void>
Description: Determine whether to set the italic effect for newly added text on the whiteboard after the text tool is selected.
setFontSize({required int fontSize}) Future<void>
Description: Set the font size for new text on the whiteboard after the text tool is selected.
setOperationMode({required int mode}) Future<void>
Set the operation mode of the current whiteboard.
setSuperBoardMaxScaleFactor({required double maxScaleFactor}) Future<void>
Set the maximum zoom factor of Super Whiteboard (files and whiteboards), which is 3x by default. The range that can be set is 1,10
setToolType({required ZegoSuperBoardTool toolType}) Future<void>
Tool (teaching tool) that operates the whiteboard view. Tools include the pen, text, straight line, and laser pen. You can set this attribute to change the tool type. Supported version: 2.0.0
setWhiteboardBackgroundColor({required String? rgbValue}) Future<void>
Set the background color for a whiteboard in the container.
stopPlayPPTVideo() Future<void>
Stop the video playing on the current page of an animated PPT file.
switchExcelSheet({required int? sheetIndex}) Future<Map?>
switchSuperBoardSubView({required String? uniqueID}) Future<ZegoSuperBoardError>
Switch to the specified SuperBoardSubView.
switchSuperBoardSubViewWithSheetIndex({required String? uniqueID, required int sheetIndex}) Future<ZegoSuperBoardError>
Switch to the specified SuperBoardSubView.
toString() String
A string representation of this object.
inherited
undo() Future<void>
Cancel the previous operation on a whiteboard.
unInit() Future<void>
De-initialize the SDK.
uploadFile({required String filePath, required ZegoSuperBoardRenderType renderType}) Future<Map?>
Upload files to the ZegoDocs service.
uploadH5File({required String filePath, required ZegoUploadCustomH5Config? config}) Future<Map?>
Upload custom H5 courseware to the ZegoDocs service.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ZegoSuperBoardManager
Singleton instance
final
methodChannel MethodChannel
Exposing methodChannel to other files
no setter