cancelCacheFile method

Future<ZegoSuperBoardError> cancelCacheFile({
  1. required int seq,
})

Cancel the caching operation during file caching.

Supported version: 2.0.0 and above

Description: Enter the seq of a file caching operation to cancel it. After the operation is canceled, files are not cached in a local directory.

Business scenario: Cancel a file caching operation that is being performed by calling the cancelCacheFile method.

Calling time: Call this API after initWithConfig.

Related APIs: cacheFile

@param seq Seq of the caching operation @param completionBlock Callback of the caching operation cancellation result

Implementation

Future<ZegoSuperBoardError> cancelCacheFile({
  required int seq,
}) async {
  var map = await _channel.invokeMethod('cancelCacheFile', {
    'seq': seq,
  });
  return ZegoSuperBoardError(map['errorCode']);
}