flipToPage method

Future<ZegoSuperBoardError> flipToPage({
  1. required int targetPage,
})

Redirect to the specified page.

Supported version: 2.0.0 and above

Description: Redirect to the specified page.

Business scenario: Specify a page to redirect.

Note: For animated PPT or H5 files, images and animations may need to be downloaded during page turning. Frequent calls may cause a long period of time to turn pages.

Related APIs: flipToPrePage and flipToNextPage

Calling time: Call this API when currentSuperBoardSubView exists.

@param targetPage Page number of the target page, which starts from 1. @return ZegoSuperBoardError

Implementation

Future<ZegoSuperBoardError> flipToPage({required int targetPage}) async {
  var map =
      await _channel.invokeMethod('flipToPage', {'targetPage': targetPage});
  return ZegoSuperBoardError(map['errorCode']);
}