flipToPrePage method

Future<ZegoSuperBoardError> flipToPrePage()

Redirect to the previous page.

Supported version: 2.0.0 and above

Description: Redirect to the previous page.

Note: For animated PPT or H5 files, images and animations may need to be downloaded during page turning. Frequent calls may cause a long period of time to turn pages.

Related APIs: flipToPage and flipToNextPage

Calling time: Call this API when currentSuperBoardSubView exists.

@return ZegoSuperBoardError

Implementation

Future<ZegoSuperBoardError> flipToPrePage() async {
  var map = await _channel.invokeMethod('flipToPrePage');
  return ZegoSuperBoardError(map['errorCode']);
}