setToolType method
Tool (teaching tool) that operates the whiteboard view. Tools include the pen, text, straight line, and laser pen. You can set this attribute to change the tool type. Supported version: 2.0.0
Description: Set different tool types to draw different diagram elements on a whiteboard.
Calling time: Call this API after the ZegoSuperBoard SDK is initialized.
Implementation
Future<void> setToolType({required ZegoSuperBoardTool toolType}) async {
return await _channel.invokeMethod('setToolType', {
'toolType': toolType.value,
});
}